translate.lang.ar

Package translate :: Package lang :: Module ar |
[hide private]
[frames] | no frames]

# Module ar

source code

This module represents Arabic language.

For more information, see http://en.wikipedia.org/wiki/Arabic_language

Classes | [hide private]
| ar This class represents Arabic.

Functions | [hide private]
reverse_quotes(text) | source code

Variables | [hide private]
| __package__ = ``'``translate.lang``'``

Imports: re, common